@@ -41,7 +41,12 @@ if not os.path.exists(USER_DATA_PATH):
 
 # setup pulseaudio socket
 pulse_socket = f"{USER_DATA_PATH}/pulseaudio.socket"
+tmp_file = '/tmp/rete_setup'
+if not os.path.exists(tmp_file) and os.path.exists(pulse_socket):
+    Path(pulse_socket).unlink()
+
 if not os.path.exists(pulse_socket):
+    Path(tmp_file).touch()
     create_pulse_socket = (
         f"pactl load-module module-native-protocol-unix socket={pulse_socket}"
     )
